searchData={"items":[{"type":"module","title":"Escript.Example","doc":"This is an example on how to use `Nexus` with an\nescript application.\n\nAfter defined `:escript` entry into your `project/0` function\non `mix.exs` and set the `main_module` option, you can safely\ndefine your commands as usual with `defcommand/2`, CLI config\nand handlers.\n\nThen you need to call `parse/0` macro, which will inject both\n`parse/1` and `run/1` function, which the latter you can delegate\nfrom the `main/1` escript funciton, as can seen below.","ref":"Escript.Example.html"},{"type":"function","title":"Escript.Example.main/1","doc":"","ref":"Escript.Example.html#main/1"},{"type":"function","title":"Escript.Example.parse/1","doc":"","ref":"Escript.Example.html#parse/1"},{"type":"function","title":"Escript.Example.run/1","doc":"","ref":"Escript.Example.html#run/1"},{"type":"task","title":"mix example","doc":"This is a Mix Task example using Nexus.\nBasically, you can `use` both `Mix.Task` and `Nexus`\nmodules, define your commands as usual with `defcommand/2`\nand implement others callbacks.\n\nThen you need to call `Nexus.parse/0`, that will inject\nboth `parse/1` and `run/1` functions into your module.\nIn a `Mix.Task` module, the `run/1` function will supply\nthe behaviour, so you don't need to define it yourself.\n\nIf you need to do other computations inside `Mix.Task.run/1`,\nthen simply define `run/1` by yourself and call `__MODULE__.run/1`\nwhen you need it, passing the raw args to it.","ref":"Mix.Tasks.Example.html"},{"type":"function","title":"Mix.Tasks.Example.parse/1","doc":"","ref":"Mix.Tasks.Example.html#parse/1"},{"type":"function","title":"Mix.Tasks.Example.run/1","doc":"","ref":"Mix.Tasks.Example.html#run/1"},{"type":"module","title":"Nexus","doc":"Nexus can be used to define simple to complex CLI applications.\n\nThe main component of Nexus is the macro `defcommand/2`, used\nto register CLI commands. Notice that the module that uses `Nexus`\nis defined as a complete CLI, with own commands and logic.\n\nTo define a command you need to name it and pass some options:\n\n- `:type`: the argument type to be parsed to. The absense of this option\nwill define a command without arguments, which can be used to define a subcommand\ngroup. See more on the [Types](#types) section.\n- `:required`: defines if the presence of the command is required or not. All commands are required by default. If you define a command as not required, you also need to define a default value.\n- `:default`: defines a default value for the command. It can be any term, but it must be of the same type as the `:type` option.","ref":"Nexus.html"},{"type":"module","title":"Usage - Nexus","doc":"defmodule MyCLI do\n      use Nexus\n\n      defcommand :foo, type: :string, required?: true\n\n      @impl true\n      def handle_input(:foo, _args) do\n        IO.puts(\"Hello :foo command!\")\n      end\n\n      Nexus.parse()\n\n      __MODULE__.run(System.argv())\n    end","ref":"Nexus.html#module-usage"},{"type":"module","title":"Types - Nexus","doc":"Nexus supports the following types:\n- `:string`: parses the argument as a string. This is the default type.\n- `:integer`: parses the argument as an integer.\n- `:float`: parses the argument as a float.\n- `:null`: parses the argument as a null value. This is useful to define subcommands.\n- `{:enum, values_list}`: parses the argument as a literal, but only if it is included into the `values_list` list. Note that current it only support string or atom values.","ref":"Nexus.html#module-types"},{"type":"macro","title":"Nexus.defcommand/2","doc":"Like `def/2`, but registers a command that can be invoked\nfrom the command line. The `@doc` module attribute and the\narguments metadata are used to generate the CLI options.\n\nEach defined command produces events that can be handled using\nthe `Nexus.CLI` behaviour, where the event is the command\nname as an atom and the second argument is a list of arguments.","ref":"Nexus.html#defcommand/2"},{"type":"macro","title":"Nexus.defcommand/3","doc":"","ref":"Nexus.html#defcommand/3"},{"type":"macro","title":"Nexus.help/0","doc":"Generates a default `help` command for your CLI. It uses the\noptional `banner/0` callback from `Nexus.CLI` to complement\ndescription.\n\nYou can also define your own `help` command, copying the `quote/2`\nblock of this macro.","ref":"Nexus.html#help/0"},{"type":"function","title":"Nexus.help/1","doc":"Given a module which defines a CLI with `Nexus`, builds\na default help string that can be printed safelly.\n\nThis function is used when you use the `help/0` macro.","ref":"Nexus.html#help/1"},{"type":"macro","title":"Nexus.parse/0","doc":"Generates three functions that can be used to manage and run\nyour CLI.\n\n### `__commands__/0`\n\nReturn all commands that were defined into your CLI module.\n\n### `run/1`\n\nRun your CLI against argv content. Notice that this function only runs\na single command and returns `:ok`. It can be used to easily define\nmix tasks.\n\nAlso this function expects that the `handle_input/2` callback from `Nexus.CLI`\nwould have some implementation for the a comand `N` that would be parsed.\n\n### `parse/1`\n\nBuild a CLI based on argv content. It can be used if you want to manage\nyour CLI or decide how you want to execute functions. It builds a map\nwhere given commands and options parsed will be keys and those values.\n\n##","ref":"Nexus.html#parse/0"},{"type":"macro","title":"Example - Nexus.parse/0","doc":"{:ok, cli} = MyCLI.parse(System.argv)\n    cli.mycommand # `arg` to `mycommand`","ref":"Nexus.html#parse/0-example"},{"type":"type","title":"Nexus.command/0","doc":"","ref":"Nexus.html#t:command/0"},{"type":"behaviour","title":"Nexus.CLI","doc":"Define callback that a CLI module needs to follow to be able\nto be runned and also define helper functions to parse a single\ncommand againts a raw input.","ref":"Nexus.CLI.html"},{"type":"callback","title":"Nexus.CLI.banner/0","doc":"","ref":"Nexus.CLI.html#c:banner/0"},{"type":"function","title":"Nexus.CLI.build/2","doc":"","ref":"Nexus.CLI.html#build/2"},{"type":"callback","title":"Nexus.CLI.handle_input/1","doc":"","ref":"Nexus.CLI.html#c:handle_input/1"},{"type":"callback","title":"Nexus.CLI.handle_input/2","doc":"","ref":"Nexus.CLI.html#c:handle_input/2"},{"type":"callback","title":"Nexus.CLI.version/0","doc":"","ref":"Nexus.CLI.html#c:version/0"},{"type":"type","title":"Nexus.CLI.t/0","doc":"","ref":"Nexus.CLI.html#t:t/0"},{"type":"module","title":"Nexus.Command","doc":"Defines a command entry for a CLI module. It also\nimplements some basic validations.","ref":"Nexus.Command.html"},{"type":"function","title":"Nexus.Command.parse!/1","doc":"","ref":"Nexus.Command.html#parse!/1"},{"type":"type","title":"Nexus.Command.t/0","doc":"","ref":"Nexus.Command.html#t:t/0"},{"type":"module","title":"Nexus.Command.Input","doc":"Define a structure to easy pattern matching the input\non commands dispatched","ref":"Nexus.Command.Input.html"},{"type":"function","title":"Nexus.Command.Input.parse!/2","doc":"","ref":"Nexus.Command.Input.html#parse!/2"},{"type":"type","title":"Nexus.Command.Input.t/0","doc":"","ref":"Nexus.Command.Input.html#t:t/0"},{"type":"module","title":"Nexus.Command.Validation","doc":"Defines validations for a `Nexus.Command` struct","ref":"Nexus.Command.Validation.html"},{"type":"function","title":"Nexus.Command.Validation.validate_default/1","doc":"","ref":"Nexus.Command.Validation.html#validate_default/1"},{"type":"function","title":"Nexus.Command.Validation.validate_name/1","doc":"","ref":"Nexus.Command.Validation.html#validate_name/1"},{"type":"function","title":"Nexus.Command.Validation.validate_required/3","doc":"","ref":"Nexus.Command.Validation.html#validate_required/3"},{"type":"function","title":"Nexus.Command.Validation.validate_type/1","doc":"","ref":"Nexus.Command.Validation.html#validate_type/1"},{"type":"module","title":"Nexus.Parser","doc":"Should parse the command and return the value","ref":"Nexus.Parser.html"},{"type":"function","title":"Nexus.Parser.run!/2","doc":"","ref":"Nexus.Parser.html#run!/2"},{"type":"module","title":"Nexus.Parser.DSL","doc":"Simple DSL to generate Regex \"parsers\" for Nexus.","ref":"Nexus.Parser.DSL.html"},{"type":"function","title":"Nexus.Parser.DSL.boolean/1","doc":"","ref":"Nexus.Parser.DSL.html#boolean/1"},{"type":"function","title":"Nexus.Parser.DSL.enum/2","doc":"","ref":"Nexus.Parser.DSL.html#enum/2"},{"type":"function","title":"Nexus.Parser.DSL.float/1","doc":"","ref":"Nexus.Parser.DSL.html#float/1"},{"type":"function","title":"Nexus.Parser.DSL.integer/1","doc":"","ref":"Nexus.Parser.DSL.html#integer/1"},{"type":"function","title":"Nexus.Parser.DSL.literal/2","doc":"","ref":"Nexus.Parser.DSL.html#literal/2"},{"type":"function","title":"Nexus.Parser.DSL.string/1","doc":"","ref":"Nexus.Parser.DSL.html#string/1"},{"type":"exception","title":"Nexus.Command.MissingType","doc":"","ref":"Nexus.Command.MissingType.html"},{"type":"exception","title":"Nexus.Command.NotSupportedType","doc":"","ref":"Nexus.Command.NotSupportedType.html"},{"type":"exception","title":"Nexus.FailedCommandParsing","doc":"","ref":"Nexus.FailedCommandParsing.html"},{"type":"extras","title":"Nexus","doc":"# Nexus\n\n⚠️ This library is highly experimental and not ready for production use! Expect breaking changes! ⚠️\n\n**YOU HAVE BEEN WARNED!**\n\n```sh\n     _      __\n|\\ ||_\\/| |(_\n| \\||_/\\|_|__)\n```\n\n> Create CLIs in a magic and declarative way!\n\nAn `Elixir` library to write command line apps in a cleaner and elegant way!\n\n[![Hex.pm](https://img.shields.io/hexpm/v/nexus_cli.svg)](https://hex.pm/packages/nexus_cli)\n[![Downloads](https://img.shields.io/hexpm/dt/nexus_cli.svg)](https://hex.pm/packages/nexus_cli)\n[![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/nexus_cli)\n[![lint](https://github.com/zoedsoupe/nexus/actions/workflows/lint.yml/badge.svg)](https://github.com/zoedsoupe/nexus/actions/workflows/lint.yml)\n[![test](https://github.com/zoedsoupe/nexus/actions/workflows/test.yml/badge.svg)](https://github.com/zoedsoupe/nexus/actions/workflows/test.yml)","ref":"readme.html"},{"type":"extras","title":"Example - Nexus","doc":"```elixir dark\ndefmodule MyCLI do\n  use Nexus\n\n  defcommand :ping, type: :null, doc: \"Answers 'pong'\"\n  defcommand :fizzbuzz, type: :integer, required: true, doc: \"Plays fizzbuzz\"\n  defcommand :mode, type: {:enum, ~w[fast slow]a}, required: true, doc: \"Defines the command mode\"\n\n  @impl Nexus.CLI\n  # no input as type == :null\n  def handle_input(:ping), do: IO.puts(\"pong\")\n\n  @impl Nexus.CLI\n  # input can be named to anything\n  @spec handle_input(atom, input) :: :ok\n        when input: Nexus.Command.Input.t()\n  def handle_input(:fizzbuzz, %{value: value}) do\n    cond do\n      rem(value, 3) == 0 -> IO.puts(\"fizz\")\n      rem(value, 5) == 0 -> IO.puts(\"buzz\")\n      rem(value, 3) == 0 and rem(value, 5) == 0 -> IO.puts(\"fizzbuzz\")\n      true -> IO.puts value\n    end\n  end\n\n  def handle_input(:mode, %{value: :fast), do: IO.puts \"Hare\"\n  def handle_input(:mode, %{value: :slow), do: IO.puts \"Tortoise\"\nend\n```\n\nMore different ways to use this library can be found on the [examples](./examples) folder","ref":"readme.html#example"},{"type":"extras","title":"Why \"Nexus\" - Nexus","doc":"Nexus is a connection from two different worlds! This library connects the world of CLIs with the magic world of `Elixir`!","ref":"readme.html#why-nexus"},{"type":"extras","title":"Inspirations - Nexus","doc":"Highly inspired in [clap-rs](https://github.com/clap-rs/clap/)","ref":"readme.html#inspirations"}],"content_type":"text/markdown"}